#ifndef __CDCANALYSIS__
#define __CDCANALYSIS__

//*************************************************************************
//* -----------
//* CDCAnalysis
//* -----------
//* (Description)
//* 	Clasess to analyze CDC data.
//* (Update Record)
//*	2000/05/16  K.Fujii	Original version.
//*************************************************************************

#include "TObject.h"
#include "TH2.h"
#include "TH1E.h"
#include "TCanvas.h"

#include "CDCTrackMaker.h"

// TObjNum is a simple container for an integer.
class TObjNum : public TObject {
   private:
     Double_t  num; //! data
   public:
     TObjNum(Double_t i = 0) : num(i) { }
     ~TObjNum() { }
     void    SetNum(Double_t i) { num = i; }
     Double_t GetNum() { return num; }
     void    Print(Option_t *) { Printf("TObjNum = %g", num); }
     Bool_t   IsEqual(TObject *obj) { return num == ((TObjNum*)obj)->num; }
     Bool_t   IsSortable() const { return kTRUE; }
     Int_t    Compare(TObject *obj) { if (num > ((TObjNum*)obj)->num)
                                        return 1;
                                     else if (num < ((TObjNum*)obj)->num)
                                        return -1;
                                     else
                                        return 0; }
   ClassDef(TObjNum, 1) // Double_t object
};

class CDCAnalysis : public JSFModule {
public:
   CDCAnalysis(const Char_t *name="CDCAnalysis",
		  const Char_t *title="CDC Analysis");
   virtual ~CDCAnalysis();

   inline Int_t GetMode   ()  const    { return fMode;   }
   inline Int_t GetNwires ()  const    { return fNwires; }
   inline Double_t GetPhSum(Int_t a)    { return fPhSum[a]; }
   inline void  SetMode   (Int_t n)    { fMode    = n;   }
   inline void  SetNwires (Int_t n)    { fNwires  = n;   }
   inline void  SetChi2Cut(Double_t x) { xChi2    = x;   }
   inline void  SetNsigCut(Double_t x) { xNsigmas = x;   }
   inline void  SetPhCut(Double_t x) { xPh = x; }

   inline void  SetTrackRange(Int_t i1, Int_t i2)
   {
      fTk1st = i1; fTklast = i2;
   }

   void GetCounterInfo(Double_t &adctc1, Double_t &adctc2, Double_t &adccsi);

   Bool_t Initialize();
   Bool_t Process(Int_t ev);
   
   void Draw(Option_t *option="");

private:
   struct THdef1 {
      Char_t   title[256];
      Int_t    nxbin;
      Float_t  xmin;
      Float_t  xmax;
   };
   struct THdef2 {
      Char_t   title[256];
      Int_t    nxbin;
      Float_t  xmin;
      Float_t  xmax;
      Int_t    nybin;
      Float_t  ymin;
      Float_t  ymax;
   };
   Int_t     fMode;		//! (0,1) = (excl,incl) wire in question
   Int_t     fNwires;		//! # wires required
   Double_t  xChi2;		//! chi2 cut
   Double_t  xNsigmas;		//! n-sigma window
   Double_t  xPh;		//! Ph cut for Truncated mean
   Int_t     fTk1st;		//! 1st track to look at
   Int_t     fTklast;		//! last track to look at
   Double_t  fPhSum[100];	//! fPhSum[a] = ph sum of wire a
   TH2F    **hRes;		//! residual plots
   TH2F    **hPhSum;		//! ph sum plots
   TH2F    **hPhPk;		//! ph peak plots
   TH2F    **hPed;		//! pedestal plots
   TH1E    **hEff;		//! efficiency plots
   TH2F    **hTwk;              //! time walk plots
   TH2F    **hSgt2;             //! track error plots
   TH1E    **hEff2tk;           //! 2-track separation
   TH2F    **hSepRes;		//! residual vs 2-hit distance
   TH2F    **hTC2Sep;		//! TC2's ADC vs 2-hit distance
   TH2F    **hSumw5;		//! Charge average of w5
   TCanvas  *hcr;		//! canvas to draw residual plots
   TCanvas  *hcs;		//! canvas to draw ph sum plots
   TCanvas  *hcp;		//! canvas to draw ph peak plots
   TCanvas  *hcz;		//! canvas to draw pedestal plots
   TCanvas  *hce;		//! canvas to draw efficiency plots
   TCanvas  *hcw;               //! canvas to draw time walk plots
   TCanvas  *hcg;               //! canvas to draw track error (Sgt22) plots
   TCanvas  *hct;		//! canvas to draw 2-track separation
   TCanvas  *hcu;		//! canvas to draw Sep-Res
   TCanvas  *hca;		//! canvas to draw TC2-Sep
   TCanvas  *hcn;		//! canvas to draw hSumw5
   THdef2   *hdefr;		//! histogram parameters for hRes
   THdef2   *hdefs;		//! histogram parameters for hPhSum
   THdef2   *hdefp;		//! histogram parameters for hPhPk
   THdef2   *hdefz;		//! histogram parameters for hPed
   THdef1   *hdefe;             //! histogram parameters for hEff
   THdef2   *hdefw;             //! histogram parameters for hTwk
   THdef2   *hdefg;             //! histogram parameters for hSgt2
   THdef1   *hdeft; 		//! histogram parameters for hEff2tk
   THdef2   *hdefu;		//! histogram parameters for hSepRes
   THdef2   *hdefa;		//! histogram parameters for hTC2Sep
   THdef2   *hdefn;             //! histogram parameters for hSumw5
   static const Int_t kNh;	//! # hists
   static const Int_t kZoneX;	//! # X divisions
   static const Int_t kZoneY;	//! # Y divisions

   ClassDef(CDCAnalysis, 1) // CDC Analysis class
};

#endif


